@@ -50,7 +50,8 @@ class Pointcloud():
         self.matrix = matrix
 
         # Additionnal DATA
-        self.areas = None
+        self.devices_matrices = None
+        self.devices_names = None
 
         # Ensure that only one populate method is selected:
         conditions = [ros_msg is not None, points is not None, inpath is not None]
@@ -221,8 +222,9 @@ class Pointcloud():
         self.metadata['width'] = self.metadata['nb_points']
         return True
 
-    def set_areas(self, areas):
-        self.areas = np.asarray(areas)
+    def set_devices(self, names, matrices):
+        self.devices_names = names
+        self.devices_matrices = np.asarray(matrices)
 
     def save(self, path):
         self.save_npz(path)
@@ -237,7 +239,8 @@ class Pointcloud():
                             points=self.points,
                             rings=self.rings,
                             matrix=self.matrix,
-                            areas=self.areas)
+                            devices_names=self.devices_names,
+                            devices_matrices=self.devices_matrices)
 
     def load(self, path):
         load_path = os.path.expanduser(path)
@@ -252,8 +255,10 @@ class Pointcloud():
                 self.points = data['points']
             if 'rings' in data:
                 self.rings = data['rings']
-            if 'areas' in data:
-                self.areas = data['areas']
+            if 'devices_names' in data:
+                self.devices_names = data['devices_names']
+            if 'devices_matrices' in data:
+                self.devices_matrices = data['devices_matrices']
 
     def save_xyz(self, path):
         save_path = os.path.expanduser(path)
